==> SicoCreditPlus_v1.3.10.zip: SicoCreditPlus/CHANGELOG.md <==
# 1.3.10
- Snippets for en-GB finally translated
- Update to "borrowing request shown" status when the order is in "open" status now doesn't throw errors anymore
- Updated "financing cancelled" text and behaviour when the order wasn't cancelled but rather goes its flow

# 1.3.9
- Fixed a bug for filters if a "WARNING" was thrown as an exception
- API switch on pre-calculation set to respective API data
- Reduced WSDL Calls on object creation
- Changes when using transaction number or order number

# 1.3.8
- Extending the calculated data to include the currently best financing options for exports and filters 
  - An example for this is located in CodeBlocks.txt
- New CronJobs to calculate the cheapest rate and reset calculated values (must be started once)
- Added filter for product listing to show only financeable products up to a specifiable monthly rate
- Bugfix for order creations by CreditPlus triggers
- Bugfix for state transitions (removed duplicates, added missing)
- Added test possibility by setting the test mode active and inputting a Dealer Order Number and fixed Status
- Added "Finance now" button when payment is in addition 3 states

# 1.3.7
- Rebuilt lost payment information from orders which were edited in the backend
- Changed dependency of sico_credit_plus_payment to order preventing further data loss

# 1.3.6
- Prevent crashing when having a basket with only non-product entries
- Changing payment means in backend is now possible
- "Dispatched" status for deliveries triggers sending information to CreditPlus, can be controlled by Flow Builder

# 1.3.5
- Removed errors when using the cronjob and product feed sales channels exist
- Displayed button to continue financing in the account overview and order history a little more prominently

# 1.3.4
- Corrected Account overview, when last order is unfinished CreditPlus order

# 1.3.3
- Updated after multiple tests with different settings on product streams yielded some errors
- Removed pre-built and unused logging from Scheduled Task
- The text above the rate table on the detail page has returned. If you use only space characters, the text and its containing div will not be displayed.
- Reset the default values for productTypeID (7 -> 56) and productClassID (7 -> 11) - only on fresh installations

# 1.3.2
- Added product streams to product groups (adding products by rules instead of directly)
- Added "Most Expensive Article in Basket", "Highest Contribution to Basket" and "Highest Amount in Basket" as Rate Selectors
- The Pop-Up with the financing page doesn't close anymore if clicked outside
- The mobile rate table has been fixed and restyled a bit

# 1.3.1
- Added Cart Save from 6.4.x branch to 6.5.x branch
- Updated older migrations to work with newer Doctrine version
- Reinstate old version logging variant with own file and own levels instead of collected logging
- Update CreditPlus Backend Order view from 6.4 to 6.5

# 1.3.0
- Changed support from 6.4.x to 6.5.x

# 1.2.30
- Saving carts in custom objects before going out to CreditPlus
- Fixed minor typos in "Decision pending" e-mail

# 1.2.29
- Add CreditPlus Image to the product card of the category page

# 1.2.28
- Bugfix and Logging of Response Subscriber

# 1.2.27
- Setting "Shown as" has now effects on the Account->Bestellungen->Jetzt Finanzieren Button
- Credit Form of an Order will only be shown if the credit form is not already filled out
- The order will only be set on Payment Status "Borrowing request shown", if the order is in the open payment status

# 1.2.26
- Fix: In foreign Languages the Status mail will not be sended 
- Fix: email of cancellation send twice if triggert in backend

# 1.2.25
- Massive update for performance when using large amounts of assigned articles
- Changed "page_checkout_finish_action" to "page_checkout_finish_teaser" (because of deprecation)

# 1.2.24
- Updates error URL for inorder content iframe

# 1.2.23
- Allow display of error messages without any order ID

# 1.2.22
- Allow X-Frame for iframe payment
- Allow Transaction IDs with "W-Number-DE" and IDs with "HzV25fg" and other characters

# 1.2.21
- Status mail template: Update for true/false values in newer templates
- Status mail template: Updated older Migration file to use correct template for "plain"

# 1.2.20
- Debug-only version to test updates on updated mail data
- Status mail template: Changed default status template to contain more information from the CreditPlus contract

# 1.2.19
- Bugfix: Duplication of orders by clicking on a button is now prevented

# 1.2.18
- Plugin now multi sales channel ready

# 1.2.17
- Payment state is now showing instead of the creditplus state name in field "Finanzierungsstatus". 

# 1.2.16
- Fix: At the re-installation of the plugin, index on order_id could not be dropped

# 1.2.15
- Bugfix: Foreign key cascade migration file

# 1.2.14
- The rate table can now be shown as modal box or as a tab.

# 1.2.13
- Fix: Reinstalling does not cause database error anymore

# 1.2.12
- Fix: A cancelled order can be financed by credit plus

# 1.2.11
- Error Fixed in Confirm Page if the order is non "before order" and the cart has lesser than the minimum of the finanzing value 

# 1.2.10
- error at the status change trigger fixed

# 1.2.9
- fix for overridden session in firefox
- not properly checked empty ordernumber fixed
- Fix for error in the order status if a page is shown in a different language as german or english
- Fix "Can't drop sico_credit_plus_payment_ibfk_1" error at update
- rate table is visible at the mobile devices.

# 1.2.8
- bugfix for 404 when dipatch route is called

# 1.2.7
- update the available stock if a credit plus order ist canceled
- twice Request when entering the order detail fixed
- on non CreditPlus orders: No Request to update the cp contract

# 1.2.6
- Disable Refresh of the Contracts while reload of the order list
- add Button for refresh the contracts of the current view
- fix of the Reflection error

# 1.2.5
- Replace const text with snippets
- delete credit plus orders does not throw a failure
- add option for log into database
- Fix bugs

# 1.2.4
- Decorator Pattern does not cause any problems

# 1.2.3
- adapted text 
- adapted Default values

# 1.2.2
- Fix missing error if the contract is declined
- Centering the texts in the finish page

# 1.2.1
- Fix Chrome Cookie Bug
- Fix after payment bug

# 1.2.0
- Plugin is now Ready for 6.4. 6.3 does not work with this plugin

# 1.1.5
- Fix Voucher handling

# 1.1.4
- At inorder orders. The update of the order state does not work.
- missing order transition added
- Error through voucher fixed

# 1.1.3
- Bugfixing
- On status "declined" the User will not receive an e-mail anymore because CreditPlus sends one 

# 1.1.2
- Bugfixing
- the status mail will now send to the customer

# 1.1.1
- Fix various Bugs

# 1.1.0
- Make Sure the Inorder payment does not create a order

# 1.0.6
- Add inorder payment

# 1.0.5
- error caused through vue fixed. This Error leads to an crash of the backend
- Number of orders send to the creditplus server is limited

# 1.0.4
- Fix 6.3.0.0+ content of iframe is not loading

# 1.0.3
- Fix 6.3.0.0+ problem with the InheritanceUpdater Service 
- Fix 6.2.x Bug with vouchers

# 1.0.2
- Fix: Data will not be saved if the user changed the "Month" field in the interest option
- Fix: Data will not be saved if the user changed the "Active" field in the interest option
- Active field is now a switch field instead of a input field
- In the interest option list the productgroup will be shown

# 1.0.1
- removed the "after confirmation" option in transaction mode

# 1.0.0
- First Version of the Credit Plus Plugin

==> SicoCreditPlus_v1.4.5.zip: SicoCreditPlus/CHANGELOG.md <==
# 1.4.5
- Bugfix for order creation when storing multiple orders before finishing them on the remote side

# 1.4.4
- Backported 1.5.0 fixes to Shopware 6.6.x branch
- Delete saved orders when conversion to real order happens
- Added titles to select boxes for Status on the Order
- Sorting of financing run times in the backend
- Saving new rates in the backend now saves the run time correctly
- Exclusions of financing are queried more consistently (fixed a Session problem)
- One step on assignments for product groups has been adjusted (works before 6.7.x Upgrade and after it as well)


# 1.4.3
- Calculated rates also for variant products (enables "finance-able" filter for variants)
- Updated CodeBlocks.txt for export templates to include "financeable no" option
- Moved the removal of the payment method from two subscribers to another subscriber, which is closer to the core request

# 1.4.2
- Updated the plugin activate service
- Fixed deactivated checkout button, when other payment type was selected and CreditPlus criteria were not met
- Fixed a request when confirming sending orders by changing the dispatch status 
- Removed unused class with unnecessary var_dumps
- Fixed an automatic update for orders with setting "payment after order" and "order number as transaction number"
- Correction for trigger URLs moved from Migration to Scheduled Task
- Rebuilt rate calculations from 1.3.8 in SQL statements as Shopware objects didn't work as intended
- Mobile rate table fixed (Thanks to Balearis)

# 1.4.1
- Removed a duplicate update of state transitions
- Added technical name for payment method
- Updates after 1.3.8 through 1.3.10 from 6.5.x Plugin versions were integrated

# 1.4.0
- Updated to Shopware 6.6.x and PHP 8.2+
- Updated from 1.3.8 on Shopware 6.5.x versions

# 1.3.10
- Snippets for en-GB finally translated
- Update to "borrowing request shown" status when the order is in "open" status now doesn't throw errors anymore
- Updated "financing cancelled" text and behaviour when the order wasn't cancelled but rather goes its flow

# 1.3.9
- Fixed a bug for filters if a "WARNING" was thrown as an exception
- API switch on pre-calculation set to respective API data
- Reduced WSDL Calls on object creation
- Changes when using transaction number or order number

# 1.3.8.1
- Fixed a bug for filters if a "WARNING" was thrown as an exception
- API switch on pre-calculation set to respective API data
- Reduced WSDL Calls on object creation

# 1.3.8
- Extending the calculated data to include the currently best financing options for exports and filters 
  - An example for this is located in CodeBlocks.txt
- New CronJobs to calculate the cheapest rate and reset calculated values (must be started once)
- Added filter for product listing to show only financeable products up to a specifiable monthly rate
- Bugfix for order creations by CreditPlus triggers
- Bugfix for state transitions (removed duplicates, added missing)
- Added test possibility by setting the test mode active and inputting a Dealer Order Number and fixed Status
- Added "Finance now" button when payment is in addition 3 states

# 1.3.7
- Rebuilt lost payment information from orders which were edited in the backend
- Changed dependency of sico_credit_plus_payment to order preventing further data loss

# 1.3.6
- Prevent crashing when having a basket with only non-product entries
- Changing payment means in backend is now possible
- "Dispatched" status for deliveries triggers sending information to CreditPlus, can be controlled by Flow Builder

# 1.3.5
- Removed errors when using the cronjob and product feed sales channels exist
- Displayed button to continue financing in the account overview and order history a little more prominently

# 1.3.4
- Corrected Account overview, when last order is unfinished CreditPlus order

# 1.3.3
- Updated after multiple tests with different settings on product streams yielded some errors
- Removed pre-built and unused logging from Scheduled Task
- The text above the rate table on the detail page has returned. If you use only space characters, the text and its containing div will not be displayed.
- Reset the default values for productTypeID (7 -> 56) and productClassID (7 -> 11) - only on fresh installations

# 1.3.2
- Added product streams to product groups (adding products by rules instead of directly)
- Added "Most Expensive Article in Basket", "Highest Contribution to Basket" and "Highest Amount in Basket" as Rate Selectors
- The Pop-Up with the financing page doesn't close anymore if clicked outside
- The mobile rate table has been fixed and restyled a bit

# 1.3.1
- Added Cart Save from 6.4.x branch to 6.5.x branch
- Updated older migrations to work with newer Doctrine version
- Reinstate old version logging variant with own file and own levels instead of collected logging
- Update CreditPlus Backend Order view from 6.4 to 6.5

# 1.3.0
- Changed support from 6.4.x to 6.5.x

# 1.2.30
- Saving carts in custom objects before going out to CreditPlus
- Fixed minor typos in "Decision pending" e-mail

# 1.2.29
- Add CreditPlus Image to the product card of the category page

# 1.2.28
- Bugfix and Logging of Response Subscriber

# 1.2.27
- Setting "Shown as" has now effects on the Account->Bestellungen->Jetzt Finanzieren Button
- Credit Form of an Order will only be shown if the credit form is not already filled out
- The order will only be set on Payment Status "Borrowing request shown", if the order is in the open payment status

# 1.2.26
- Fix: In foreign Languages the Status mail will not be sended 
- Fix: email of cancellation send twice if triggert in backend

# 1.2.25
- Massive update for performance when using large amounts of assigned articles
- Changed "page_checkout_finish_action" to "page_checkout_finish_teaser" (because of deprecation)

# 1.2.24
- Updates error URL for inorder content iframe

# 1.2.23
- Allow display of error messages without any order ID

# 1.2.22
- Allow X-Frame for iframe payment
- Allow Transaction IDs with "W-Number-DE" and IDs with "HzV25fg" and other characters

# 1.2.21
- Status mail template: Update for true/false values in newer templates
- Status mail template: Updated older Migration file to use correct template for "plain"

# 1.2.20
- Debug-only version to test updates on updated mail data
- Status mail template: Changed default status template to contain more information from the CreditPlus contract

# 1.2.19
- Bugfix: Duplication of orders by clicking on a button is now prevented

# 1.2.18
- Plugin now multi sales channel ready

# 1.2.17
- Payment state is now showing instead of the creditplus state name in field "Finanzierungsstatus". 

# 1.2.16
- Fix: At the re-installation of the plugin, index on order_id could not be dropped

# 1.2.15
- Bugfix: Foreign key cascade migration file

# 1.2.14
- The rate table can now be shown as modal box or as a tab.

# 1.2.13
- Fix: Reinstalling does not cause database error anymore

# 1.2.12
- Fix: A cancelled order can be financed by credit plus

# 1.2.11
- Error Fixed in Confirm Page if the order is non "before order" and the cart has lesser than the minimum of the finanzing value 

# 1.2.10
- error at the status change trigger fixed

# 1.2.9
- fix for overridden session in firefox
- not properly checked empty ordernumber fixed
- Fix for error in the order status if a page is shown in a different language as german or english
- Fix "Can't drop sico_credit_plus_payment_ibfk_1" error at update
- rate table is visible at the mobile devices.

# 1.2.8
- bugfix for 404 when dipatch route is called

# 1.2.7
- update the available stock if a credit plus order ist canceled
- twice Request when entering the order detail fixed
- on non CreditPlus orders: No Request to update the cp contract

# 1.2.6
- Disable Refresh of the Contracts while reload of the order list
- add Button for refresh the contracts of the current view
- fix of the Reflection error

# 1.2.5
- Replace const text with snippets
- delete credit plus orders does not throw a failure
- add option for log into database
- Fix bugs

# 1.2.4
- Decorator Pattern does not cause any problems

# 1.2.3
- adapted text 
- adapted Default values

# 1.2.2
- Fix missing error if the contract is declined
- Centering the texts in the finish page

# 1.2.1
- Fix Chrome Cookie Bug
- Fix after payment bug

# 1.2.0
- Plugin is now Ready for 6.4. 6.3 does not work with this plugin

# 1.1.5
- Fix Voucher handling

# 1.1.4
- At inorder orders. The update of the order state does not work.
- missing order transition added
- Error through voucher fixed

# 1.1.3
- Bugfixing
- On status "declined" the User will not receive an e-mail anymore because CreditPlus sends one 

# 1.1.2
- Bugfixing
- the status mail will now send to the customer

# 1.1.1
- Fix various Bugs

# 1.1.0
- Make Sure the Inorder payment does not create a order

# 1.0.6
- Add inorder payment

# 1.0.5
- error caused through vue fixed. This Error leads to an crash of the backend
- Number of orders send to the creditplus server is limited

# 1.0.4
- Fix 6.3.0.0+ content of iframe is not loading

# 1.0.3
- Fix 6.3.0.0+ problem with the InheritanceUpdater Service 
- Fix 6.2.x Bug with vouchers

# 1.0.2
- Fix: Data will not be saved if the user changed the "Month" field in the interest option
- Fix: Data will not be saved if the user changed the "Active" field in the interest option
- Active field is now a switch field instead of a input field
- In the interest option list the productgroup will be shown

# 1.0.1
- removed the "after confirmation" option in transaction mode

# 1.0.0
- First Version of the Credit Plus Plugin
